summaryrefslogtreecommitdiff
path: root/sw/source/core/inc/node2lay.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/core/inc/node2lay.hxx')
-rw-r--r--sw/source/core/inc/node2lay.hxx24
1 files changed, 12 insertions, 12 deletions
diff --git a/sw/source/core/inc/node2lay.hxx b/sw/source/core/inc/node2lay.hxx
index e424c4f79e27..292fd7b6fbca 100644
--- a/sw/source/core/inc/node2lay.hxx
+++ b/sw/source/core/inc/node2lay.hxx
@@ -30,23 +30,23 @@
* the relevant ones are returned. Repeated table headers are also taken
* into account.
* It's possible to iterate over SectionNodes that are either not directly
* assigned to a SectionFrm or to multiple ones due to nesting.
*
* This class is an interface between the method and a SwClientIter: it
* chooses the right SwModify depending on the task, creates a SwClientIter
* and filters its iterations depending on the task.
* The task is determined by the choice of ctor.
*
* 1. Collecting the UpperFrms (so that later on it becomes RestoreUpperFrms)
* is called by MakeFrms, if there's no PrevNext (before/after we can insert
* the Frames).
* 2. Inserting the Frames before/after which the new Frames of a Node need to
* be inserted, is also called by MakeFrms.
*/
class SwNode2LayImpl;
-class SwFrm;
-class SwLayoutFrm;
+class SwFrame;
+class SwLayoutFrame;
class SwNode;
class SwNodes;
class Point;
@@ -56,20 +56,20 @@ class SwNode2Layout
{
std::unique_ptr<SwNode2LayImpl> pImpl;
public:
/// Use this ctor for collecting the UpperFrms
SwNode2Layout( const SwNode& rNd );
/// Use this ctor for inserting before/after rNd
/// @param nIdx is the index of the to-be-inserted Node
SwNode2Layout( const SwNode& rNd, sal_uLong nIdx );
~SwNode2Layout();
- SwFrm* NextFrm();
- SwLayoutFrm* UpperFrm( SwFrm* &rpFrm, const SwNode& rNode );
- void RestoreUpperFrms( SwNodes& rNds, sal_uLong nStt, sal_uLong nEnd );
+ SwFrame* NextFrame();
+ SwLayoutFrame* UpperFrame( SwFrame* &rpFrame, const SwNode& rNode );
+ void RestoreUpperFrames( SwNodes& rNds, sal_uLong nStt, sal_uLong nEnd );
- SwFrm *GetFrm( const Point* pDocPos = nullptr,
+ SwFrame *GetFrame( const Point* pDocPos = nullptr,
const SwPosition *pPos = nullptr,
- const bool bCalcFrm = true ) const;
+ const bool bCalcFrame = true ) const;
};
#endif
@@ -30,23 +30,23 @@
* into account.
* It's possible to iterate over SectionNodes that are either not directly
- * assigned to a SectionFrm or to multiple ones due to nesting.
+ * assigned to a SectionFrame or to multiple ones due to nesting.
*
* This class is an interface between the method and a SwClientIter: it
@@ -30,23 +30,23 @@
* The task is determined by the choice of ctor.
*
- * 1. Collecting the UpperFrms (so that later on it becomes RestoreUpperFrms)
- * is called by MakeFrms, if there's no PrevNext (before/after we can insert
+ * 1. Collecting the UpperFrames (so that later on it becomes RestoreUpperFrames)
+ * is called by MakeFrames, if there's no PrevNext (before/after we can insert
* the Frames).
* 2. Inserting the Frames before/after which the new Frames of a Node need to
@@ -30,23 +30,23 @@
* the Frames).
* 2. Inserting the Frames before/after which the new Frames of a Node need to
- * be inserted, is also called by MakeFrms.
+ * be inserted, is also called by MakeFrames.
*/
class SwNode2LayImpl;
@@ -56,20 +56,20 @@ class SwNode2Layout
std::unique_ptr<SwNode2LayImpl> pImpl;
public:
- /// Use this ctor for collecting the UpperFrms
+ /// Use this ctor for collecting the UpperFrames
SwNode2Layout( const SwNode& rNd );
/// Use this ctor for inserting before/after rNd